@@ -6,6 +6,9 @@ from .bpemblang import BytePairLanguage
 from .bpemblang import BytePairLanguage as BytePairLang
 from .convert_lang import ConveRTLanguage
 from .gensim_lang import GensimLanguage
+from .tfhub_lang import TFHubLanguage
+from .hftransformers_lang import HFTransformersLanguage
+
 
 __all__ = [
     "SpacyLanguage",
@@ -16,4 +19,6 @@ __all__ = [
     "BytePairLanguage",
     "GensimLanguage",
     "ConveRTLanguage",
+    "TFHubLanguage",
+    "HFTransformersLanguage",
 ]
