@@ -7,9 +7,10 @@ from bpemb import BPEmb
 from sklearn.metrics import pairwise_distances
 
 from whatlies import Embedding, EmbeddingSet
+from whatlies.language.common import SklearnTransformerMixin
 
 
-class BytePairLanguage:
+class BytePairLanguage(SklearnTransformerMixin):
     """
     This object is used to lazily fetch [Embedding][whatlies.embedding.Embedding]s or
     [EmbeddingSet][whatlies.embeddingset.EmbeddingSet]s from a Byte-Pair Encoding
